pype32.directories.NetDirectory

Package pype32 :: Module directories :: Class NetDirectory |
[hide private]
[frames] | no frames]

# Class NetDirectory

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 NetDirectory

NetDirectory object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) A class representation of the `IMAGE_COR20_HEADER` structure. | source code
getType(self) Returns consts.IMAGE_COR20_HEADER. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
NetDirectory |
parse(readDataInstance) Returns a new NetDirectory object. | source code

Instance Variables | [hide private]
| cb DWORD cb.
| majorRuntimeVersion WORD majorRuntimeVersion.
| minorRuntimeVersion WORD minorRuntimeVersion.
| metaData Directory metaData.
| flags DWORD flags.
| entryPointToken DWORD entryPointToken.
| resources Directory resources.
| strongNameSignature Directory strongNameSignature.
| codeManagerTable Directory codeManagerTable.
| vTableFixups Directory vTableFixups.
| exportAddressTableJumps Directory exportAddressTableJumps.
| managedNativeHeader Directory managedNativeHeader.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
A class representation of the `IMAGE_COR20_HEADER` structure. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: http://www.ntcore.com/files/dotnetformat.htm

### getType(self) | source code
Returns consts.IMAGE_COR20_HEADER. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType

### parse(readDataInstance) Static Method | source code
Returns a new NetDirectory object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a NetDirectory object. Returns: NetDirectory A new NetDirectory object.